;; Swahili Voice definition

;; SYSTEM DEPENDENT PATHS in case you want to provide absolute paths to data (TO FIX)
;; (defvar kw_data_dir1 "/home/kssha/SWAHILI_NEW/swahili/")
;;(defvar kw_data_dir "/swahili/db/../festival/libdir")

;; Relative paths to data

(defvar kw_data_dir1 (path-append libdir "../../kiswahili/UON_swahili_kw_multisyn"))
(defvar kw_data_dir (path-append libdir "../../kiswahili/UON_swahili_kw_multisyn/db"))


;; SCHEME PATHS

(defvar multisyn_lib_dir (path-append libdir "multisyn/"))
(defvar kw_multisyn_dir (cdr (assoc 'kw_multisyn voice-locations)))
(if (not (member_string multisyn_lib_dir libdir))
  (set! load-path (cons multisyn_lib_dir load-path)))
(load (path-append kw_data_dir1 "files_scm/" (string-append 'UON_swahili_kw_lexicon ".scm")))
(set! load-path (cons (path-append kw_data_dir1 "files_scm/") 
		      load-path))


;; REQUIRES
(require 'UON_swahili_kw_lexicon)
(require 'UON_swahili_kw_f0model)
(require 'UON_swahili_kw_phoneset)
(require 'multisyn)
(require 'UON_swahili_kw_phrasing)
(require 'UON_swahili_kw_tokenizer)
(require 'UON_swahili_kw_intonation)
(require 'UON_swahili_kw_tagger)
(require 'UON_swahili_kw_phrasing)

;; DATA PATHS

;; Location of Base utterances
(set! kw_base_dirs (list (path-append kw_data_dir "utt/")
			   (path-append kw_data_dir "lpc/")
			   (path-append kw_data_dir "lpc/")
			   (path-append kw_data_dir "coef_stripped/")
			   ".utt" ".res" ".lpc" ".coef"))

;; Location of Pauses
;; These are currently silence so we just use the waveforms
(set! kw_pauses_dirs (list (path-append kw_data_dir "pauses/utt/")
			     (path-append kw_data_dir "pauses/wav/")
			     (path-append kw_data_dir "pauses/pm/")
			     (path-append kw_data_dir "pauses/coef/")))

(make_voice_definition 'UON_swahili_kw_multisyn
		       16000
		       'voice_UON_swahili_kw_multisyn_configure
		       swahili-backoff_rules
		       kw_data_dir
		       (list (list kw_base_dirs "utts.data")
			    (list kw_pauses_dirs "utts.pauses")))
			
(define (voice_UON_swahili_kw_multisyn_configure voice)
  "(voice_UON_swahili_kw_multisyn_configure voice)
 Set up the current voice to be male Scottish English (kw) for
 the multisyn unitselection engine."
    (voice_reset)
    (Parameter.set 'Language 'swahili)
    (UON_swahili_kw::select_phoneset)
    (UON_swahili_kw::select_tokenizer)
    (UON_swahili_kw::select_lexicon)
    (UON_swahili_kw::select_tagger)
    (UON_swahili_kw::select_phrasing)
    (Parameter.set 'Pause_Method MultiSyn_Pauses)
    (Parameter.set 'Int_Method nil)
    (Parameter.set 'Int_Target_Method nil)
    (Parameter.set 'Duration_Method nil)
    (Param.set 'Synth_Method 'MultiSyn)
    (Param.set 'unisyn.window_symmetric 0)
)
    
(proclaim_voice
 'UON_swahili_kw_multisyn
 '((language swahili)(gender male)(dialect kiugunja)
   (description "Kw multisyn unitsel voice (default configuration).")))


(provide 'UON_swahili_kw_multisyn)
